@@ -49,9 +49,9 @@ class ScriptingHtmlDialog : public QDialog {
 
             QDialogButtonBox *buttonBox = new QDialogButtonBox(this);
             buttonBox->setStandardButtons(QDialogButtonBox::Close);
-            connect(buttonBox, SIGNAL(accepted()), this, SLOT(slotClose()));
+            connect(buttonBox, SIGNAL(accepted()), this, SLOT(slotClose())); // NOTE 2015-01-25: no such slot
             connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-            connect(buttonBox, SIGNAL(rejected()), this, SLOT(slotClose()));
+            connect(buttonBox, SIGNAL(rejected()), this, SLOT(slotClose())); // NOTE 2015-01-25: no such slot
             connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
             QVBoxLayout *layout = new QVBoxLayout;
@@ -109,7 +109,7 @@ void Scripting::runScript(const QString &path, const QString &name) {
     QUrl fileName = QUrl::fromLocalFile(path + "index.html");
     if(!mScriptingHtmlDialog) {
         mScriptingHtmlDialog = new ScriptingHtmlDialog(this);
-        connect(mScriptingHtmlDialog, SIGNAL(closeClicked()), SLOT(stopAllScripts()));
+        connect(mScriptingHtmlDialog, SIGNAL(closeClicked()), SLOT(stopAllScripts()));  // NOTE 2015-01-25: no such signal
 
         QAction *refreshAction = new QAction("refresh", mScriptingHtmlDialog);
         refreshAction->setShortcut(QKeySequence::Refresh);
@@ -200,7 +200,7 @@ void Scripting::runScriptSlot() {
     QList<KSysGuard::Process *> selectedProcesses = mProcessList->selectedProcesses();
     if(selectedProcesses.isEmpty())
         return;
-    mPid = selectedProcesses[0]->pid;
+    mPid = selectedProcesses[0]->pid();
 
     runScript(path, action->text());
 }
